@@ -77,7 +77,11 @@ pcadapt <- function(input,
     }
     shiny::runApp(appDir, display.mode = "normal")  
   } else {
-    UseMethod("pcadapt")
+    if (grepl("^pcadapt_", class(input))) {
+      UseMethod("pcadapt")
+    } else {
+      stop("Remember to always use read.pcadapt() before using pcadapt().")
+    }
   }
 }
 
